<?php
// $Id: definitions.install, v 0.1, 2011/02/24 13:57:32, admin Exp $

/**
 * @file
 *
 * Administration file for the definitions module.
 */


/**
 *
 */
function definitions_page() {
  $definitions = definitions_load_mutiple();

  if (empty($definitions)) {
    return t('There are no definitions yet. Click !link to add one.', array('!link' => l(t('here'), 'admin/structure/definitions/add')));
  }

  $rows = array();
  $header = array(t('Definition'), t('Explanation'), t('Actions'));

  foreach ($definitions as $did => $definition) {
    $rows[] = array(
      $definition->definition,
      $definition->explanation,
      array(
        'data' => l(t('edit'), 'admin/structure/definitions/' . $did . '/edit') . l(t('delete'), 'admin/structure/definitions/' . $did . '/delete'),
        'class' => 'actions',
      ),
    );
  }

  return theme('table', array('header' => $header, 'rows' => $rows, 'attributes' => array('class' => array('definitions_overview'))));
}


/**
 *
 */
function definitions_form($form, $form_state, $definition = NULL) {
  $form = array('definition' => array('#tree' => TRUE));

  $form['definition']['did'] = array(
    '#type' => 'value',
    '#value' => ($definition ? $definition->did : NULL),
  );
  $form['definition']['definition'] = array(
    '#type' => 'textfield',
    '#title' => t('Definition'),
    '#default_value' => ($definition ? $definition->definition : ''),
    '#description' => t(''),
    '#required' => TRUE,
  );
  $form['definition']['explanation'] = array(
    '#type' => 'textarea',
    '#title' => t('Explanation'),
    '#default_value' => ($definition ? $definition->explanation : ''),
    '#description' => t(''),
    '#required' => TRUE,
  );
  $form['definition']['extra_class'] = array(
    '#type' => 'textfield',
    '#title' => t('Extra class'),
    '#default_value' => ($definition ? $definition->extra_class : ''),
    '#description' => t(''),
  );
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Submit'),
  );

  return $form;
}

/**
 * Submit callback for the definitions form.
 */
function definitions_form_validate($form, &$form_state) {
  $definition = (object) $form_state['values']['definition'];
  if (definition_exists($definition)) {
    form_set_error('definition][definition', t('This definition already exists!'));
  }
}

/**
 * Submit callback for the definitions form.
 */
function definitions_form_submit($form, &$form_state) {
  definition_save((object) $form_state['values']['definition']);
  $form_state['redirect'] = 'admin/structure/definitions';
}


/**
 * Form defenition for deleting a definition.
 */
function definitions_delete_form($form, &$form_state, $definition) {
  $form['did'] = array(
    '#type' => 'value',
    '#value' => $definition->did,
  );
  $form['definition'] = array(
    '#type' => 'value',
    '#value' => $definition->definition,
  );
  return confirm_form($form, t('Are you sure you want to delete the definition %definition', array('%definition' => $definition->definition)), 'admin/structure/definitions', t('This action cannot be undone.'), t('Delete'), t('Cancel'));
}

/**
 * Submit callback for definitions_delete_form().
 */
function definitions_delete_form_submit($form, &$form_state) {
  // TODO Please review the conversion of this statement to the D7 database API syntax.
  /* db_query("DELETE FROM {definitions} WHERE did = %d", $form_state['values']['did']) */
  db_delete('definitions')
  ->condition('did', $form_state['values']['did'])
  ->execute();
  $form_state['redirect'] = 'admin/structure/definitions';
  drupal_set_message(t('The definition %definition has been deleted', array('%definition' => $form_state['values']['definition'])));
}
